%define name NVIDIA_nforce
%define version 1.0
%define release 0274
Summary: NVIDIA Linux drivers for nForce chipsets
Name: %{name}
Version: %{version}
Release: %{release}
Source0: nvnet.tgz
Source1: nvaudio.tgz
Source2: nvmaster.tgz
Source3: nvgart.tgz
License: commercial
Group: kernel/drivers
Prefix: %{_prefix}
ExcludeArch: sparc alpha
ExclusiveOS: linux
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

# Don't strip object files
%define __spec_install_post /usr/lib/rpm/brp-compress

# disable building of debug packages
%define debug_package ${nil}

%description
This package contains drivers and documentation for the nForce,
nForce2, and nForce3 chipsets. It also contains instructions for 
configuring the IDE and USB hardware correctly.  The audio driver is 
based the i810 audio driver; the GPL licence for that driver is included.

%prep
echo "---- Copying Sources ----"
%setup -n nforce
%setup -T -D -b 1 -n nforce
%setup -T -D -b 2 -n nforce
%setup -T -D -b 3 -n nforce

%build
echo "---- Building Drivers ----"
make

%install
echo "---- Installing Drivers ----"

rm -f %{_topdir}/BUILD/nforce/modules.list

# Use current kernel if rebuilding a source RPM
if [ -z "$TARGET_KERNEL" ]; then
	export TARGET_KERNEL=`uname -r`
fi

make INSTROOT="$RPM_BUILD_ROOT" install
echo "%attr(644, root, root) /lib/modules/$TARGET_KERNEL/kernel/drivers/sound/nvaudio.o" > %{_topdir}/BUILD/nforce/modules.list
echo "%attr(644, root, root) /lib/modules/$TARGET_KERNEL/kernel/drivers/net/nvnet.o" >> %{_topdir}/BUILD/nforce/modules.list

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%post
/sbin/depmod -a

# Update the configuration file
# Only do this the first time the modules are installed
if [ $1 = 1 ] ; then 
    #Decide on the naming convention
    configmod="/etc/conf.modules"
    [ -f /etc/modules.conf ] && configmod="/etc/modules.conf"

    # comment out nvnet if it already exists
    perl -i -pe 's/^alias\s*eth\d*\s*nvnet/#$&/' $configmod

    # Modify: "alias ethX nvnet"
    # find first unused device number
    dev=`perl -e 'while(<>) { $x[$1]++ if (m/^alias\s*eth(\d*)/); } for ($i=0; $i<99; $i++) { last if (not $x[$i]); } print "$i\n";' < $configmod`
    echo "alias eth${dev} nvnet" >> $configmod

    # comment out i810 audio driver if it exists
    perl -i -pe 's/^alias\s*sound-slot-\d*\s*i810_audio/#$&/' $configmod

    # comment out nvaudio if it already exists
    perl -i -pe 's/^alias\s*sound-slot-\d*\s*nvaudio/#$&/' $configmod

    # Modify: "alias sound-slot-X nvaudio"
    # find first unused device number
    dev=`perl -e 'while(<>) { $x[$1]++ if (m/^alias\s*sound-slot-(\d*)/); } for ($i=0; $i<99; $i++) { last if (not $x[$i]); } print "$i\n";' < $configmod`
    echo "alias sound-slot-${dev} nvaudio" >> $configmod

    # Modify: "alias usb-interface usb-ohci"
    # comment out existing configuration
    perl -i -pe 's/^alias\s*usb-interface/#$&/' $configmod
    echo 'alias usb-interface usb-ohci' >> $configmod
fi

%postun
# If it's the last module removed
if [ $1 = 0 ]; then

    #Decide on the naming convention
    configmod="/etc/conf.modules"
    [ -f /etc/modules.conf ] && configmod="/etc/modules.conf"

    # Comment out the aliases we put in (if they're still in the file)
    # Don't copy back a backup file, since the original may have been edited
    # since the install.

    # Modify: "alias ethX nvnet"
    # comment out "alias ethX nvnet"
    perl -i -pe 's/^alias\s*eth\d*\s*nvnet/#$&/' $configmod

    # Modify: "alias sound-slot-X nvaudio"
    # comment out "alias sound-slot-X nvaudio"
    perl -i -pe 's/^alias\s*sound-slot-\d*\s*nvaudio/#$&/' $configmod

    # Modify: "alias usb-interface usb-ohci"
    # comment out "alias usb-interface usb-ohci"
    perl -i -pe 's/^alias\s*usb-interface\s*usb-ohci/#$&/' $configmod
fi
/sbin/depmod -a

# Starting at $ROOT/RPM/BUILD/nforce
%files -f modules.list
%defattr(-,root,root)
%attr(444, root, root) %doc NVLicense.txt
%attr(444, root, root) %doc GNULicense.txt
%attr(444, root, root) %doc ReleaseNotes.html
%attr(444, root, root) %{_usrsrc}/nvidia/nvgart/linux-2.4.20-agpgart.diff
%attr(444, root, root) %{_usrsrc}/nvidia/nvgart/linux-2.4.21-agpgart.diff
%attr(444, root, root) %{_usrsrc}/nvidia/nvgart/linux-2.4.22-agpgart.diff
%attr(444, root, root) %{_usrsrc}/nvidia/nvgart/README
%attr(444, root, root) %{_includedir}/nvaudio.h

%changelog

# end of file
